pub trait EciesSigner: Send + Sync {
// Required methods
fn encrypt_ecies<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
message: &'life1 [u8],
path: &'life2 DerivationPath,
) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, SdkError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn decrypt_ecies<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
message: &'life1 [u8],
path: &'life2 DerivationPath,
) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, SdkError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
ECIES encryption/decryption, keyed off a derivation path. Optional: it needs local access to key material, so a signer that keeps keys in a restricted enclave may not offer it.