pub trait HmacSigner: Send + Sync {
// Required method
fn hmac_sha256<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
key_path: &'life1 DerivationPath,
input: &'life2 [u8],
) -> Pin<Box<dyn Future<Output = Result<Hmac<Hash>, SdkError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
HMAC-SHA256 keyed off a derivation path (LNURL-auth). Optional: it needs local access to key material, so a signer that keeps keys in a restricted enclave may not offer it.
Required Methods
Sourcefn hmac_sha256<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
key_path: &'life1 DerivationPath,
input: &'life2 [u8],
) -> Pin<Box<dyn Future<Output = Result<Hmac<Hash>, SdkError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn hmac_sha256<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
key_path: &'life1 DerivationPath,
input: &'life2 [u8],
) -> Pin<Box<dyn Future<Output = Result<Hmac<Hash>, SdkError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Computes HMAC-SHA256 using a key derived at the given path.